==> dl.php?src=linea21_2_3_0.zip: linea21/languages/es/lang_newsletter.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	nommage des modules
 *  	*/
$lang['newsletter']['name']='boletín';
$lang['newsletter']['confirm_add'] = "Boletín añadido correctamente";
$lang['newsletter']['confirm_mod'] = "Boletín actualizado correctamente";
$lang['newsletter']['confirm_sup'] ="Boletín eliminado correctamente";


/*	nommage rubrique module
 *  	*/
$lang['newsletter']['add']= 'Añadir nuevo '.$lang['newsletter']['name'];
$lang['newsletter']['mod']= 'Editar '.$lang['newsletter']['name'];
$lang['newsletter']['sup']= 'Eliminar '.$lang['newsletter']['name'];
$lang['newsletter']['det']= ucfirst($lang['newsletter']['name']). ' detalles';
$lang['newsletter']['list']= 'Ver '.$lang['newsletter']['name'].'es';
$lang['newsletter']['subscribe_title']='Subscribirse al boletín';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['newsletter']['add_title']='Añadir valores al nuevo '.$lang['newsletter']['name'];
$lang['newsletter']['mod_title']='Editar valores del '.$lang['newsletter']['name'];
$lang['newsletter']['recap_commment']='sin comentarios';


/*	check integrité des données
 *  	*/
$lang['newsletter']['no_title']='El título es requerido';
$lang['newsletter']['no_body']='El cuerpo es requerido';
$lang['newsletter']['invalid_mail']= 'El email no es válido';
$lang['newsletter']['subscribe_yet']='Usted aún no está subscrito al boletín';
$lang['newsletter']['confirm_subscribe']='Usted ya está subscrito al boletín';
$lang['newsletter']['no_suscribe']='Usted no se ha subscrito al boletín';
$lang['newsletter']['confirm_del']='Subscripción realizada correctamente ';
$lang['newsletter']['subscribers_list']='Lista de inscritos al boletín';
$lang['newsletter']['email_address']='Correo electrónico';
$lang['newsletter']['search_address']='Buscar una dirección';

/*	nommage élément rubrique
 *  	*/
$lang['newsletter']['title']='título';
$lang['newsletter']['body']= 'cuerpo';
$lang['newsletter']['auto_populate']= 'Llenado automático';
$lang['newsletter']['statut']='estado';
$lang['newsletter']['author']='autor';
$lang['newsletter']['nightsend']='enviar boletín la próxima noche';


/*	nommage quickbox
 *  	*/
$lang['newsletter']['qb_titleadd']=' boletines agregados recientemente';
$lang['newsletter']['qb_titlemod']=' boletines modificados recientemente';
$lang['newsletter']['qb_titlesup']=' boletines eliminados recientemente';
$lang['newsletter']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/
$lang['newsletter']['nb_total']='boletín(es) en la base de datos.';
$lang['newsletter']['statut_filter']='Mostrar por estados';
$lang['newsletter']['all']='Mostrar lista completa';
$lang['newsletter']['noresult']='No existen boletines con este criterio ';
$lang['newsletter']['content']='Ingresar boletín aquí';
$lang['newsletter']['send_test']='Enviar prueba a %s';
$lang['newsletter']['sending_mail']='Enviando correo ...';
$lang['newsletter']['sent_successfully']='¡Boletín enviado correctamente!';
$lang['newsletter']['sent_failed']='Error de envío.';
$lang['newsletter']['test_add']='prueba';
$lang['newsletter']['unsubscribe_html']='Para cancelar suscripción de nuestro boletín, <a href="%s">haga clic en el enlace</a>.';
$lang['newsletter']['unsubscribe_txt']='Para cancelar suscripción de nuestro boletín, haga clic en el siguiente enlace:';

/*	rubrique d'aide
 *  	*/
$lang['newsletter']['help_add1']='Para añadir un boletín, inserte la información requerida en el formulario.';
$lang['newsletter']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['newsletter']['help_add3']='Validado el resumen, haga clic en "revisar valores" si desea hacer cambios.';


$lang['newsletter']['help_list1']='Para más información haga clic en el título del boletín.';
$lang['newsletter']['help_list2']="Para eliminar un boletín, haga clic en el icono 'eliminar boletín'.";
$lang['newsletter']['help_list3']="Para editar un boletín, haga clic en el icono 'editar boletín'.";
$lang['newsletter']['help_list4']='Para visualizar los boletines según su estado, mostrar por estados.';
$lang['newsletter']['help_list5']='Para añadir un boletín, haga clic en "añadir nuevo boletín".';
$lang['newsletter']['help_list6']="Si desea realizar búsquedas dentro del módulo 'boletines', haga clic en 'buscar'.";


$lang['newsletter']['help_mod1']='Para editar un boletín, complete la información requerida en el formulario.';
$lang['newsletter']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['newsletter']['help_mod3']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';


$lang['newsletter']['help_det1']="Para eliminar un boletín, haga clic en el icono 'eliminar boletín.'";
$lang['newsletter']['help_det2']="Para editar un boletín, haga clic en el icono 'editar boletín'.";

$lang['newsletter']['help_sup1']="Para abortar la eliminación, haga clic en 'cancelar'.";
?>

==> dl.php?src=linea21_2_7_0.zip: linea21/languages/es/lang_newsletter.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	nommage des modules
 *  	*/
$lang['newsletter']['name']='boletín';
$lang['newsletter']['confirm_add'] = "Boletín añadido correctamente";
$lang['newsletter']['confirm_mod'] = "Boletín actualizado correctamente";
$lang['newsletter']['confirm_sup'] ="Boletín eliminado correctamente";


/*	nommage rubrique module
 *  	*/
$lang['newsletter']['add']= 'Añadir nuevo '.$lang['newsletter']['name'];
$lang['newsletter']['mod']= 'Editar '.$lang['newsletter']['name'];
$lang['newsletter']['sup']= 'Eliminar '.$lang['newsletter']['name'];
$lang['newsletter']['det']= ucfirst($lang['newsletter']['name']). ' detalles';
$lang['newsletter']['list']= 'Ver '.$lang['newsletter']['name'].'es';
$lang['newsletter']['subscribe_title']='Subscribirse al boletín';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['newsletter']['add_title']='Añadir valores al nuevo '.$lang['newsletter']['name'];
$lang['newsletter']['mod_title']='Editar valores del '.$lang['newsletter']['name'];
$lang['newsletter']['recap_commment']='sin comentarios';


/*	check integrité des données
 *  	*/
$lang['newsletter']['no_title']='El título es requerido';
$lang['newsletter']['no_body']='El cuerpo es requerido';
$lang['newsletter']['invalid_mail']= 'El email no es válido';
$lang['newsletter']['subscribe_yet']='Usted aún no está subscrito al boletín';
$lang['newsletter']['confirm_subscribe']='Usted ya está subscrito al boletín';
$lang['newsletter']['no_suscribe']='Usted no se ha subscrito al boletín';
$lang['newsletter']['confirm_del']='Subscripción realizada correctamente ';
$lang['newsletter']['subscribers_list']='Lista de inscritos al boletín';
$lang['newsletter']['email_address']='Correo electrónico';
$lang['newsletter']['search_address']='Buscar una dirección';

/*	nommage élément rubrique
 *  	*/
$lang['newsletter']['title']='título';
$lang['newsletter']['body']= 'cuerpo';
$lang['newsletter']['auto_populate']= 'Llenado automático';
$lang['newsletter']['statut']='estado';
$lang['newsletter']['author']='autor';
$lang['newsletter']['nightsend']='enviar boletín la próxima noche';
$lang['newsletter']['scheduled']='scheduled'; // @todo translation


/*	nommage quickbox
 *  	*/
$lang['newsletter']['qb_titleadd']=' boletines agregados recientemente';
$lang['newsletter']['qb_titlemod']=' boletines modificados recientemente';
$lang['newsletter']['qb_titlesup']=' boletines eliminados recientemente';
$lang['newsletter']['qb_titlepubli']=' últimas publicaciones';


/*	divers
 *  	*/
$lang['newsletter']['nb_total']='boletín(es) en la base de datos.';
$lang['newsletter']['statut_filter']='Mostrar por estados';
$lang['newsletter']['all']='Mostrar lista completa';
$lang['newsletter']['noresult']='No existen boletines con este criterio ';
$lang['newsletter']['content']='Ingresar boletín aquí';
$lang['newsletter']['send_test']='Enviar prueba a %s';
$lang['newsletter']['send_now']='Enviar Ahora !';
$lang['newsletter']['send_confirm']='Are you sure you want to send the newsletter now ?'; // @todo translation
$lang['newsletter']['sending_mail']='Enviando correo ...';
$lang['newsletter']['sent_successfully']='¡Boletín enviado correctamente!';
$lang['newsletter']['sent_failed']='Error de envío.';
$lang['newsletter']['already_sent']='The newsletter has already been sent.'; // @todo translation
$lang['newsletter']['test_add']='prueba';
$lang['newsletter']['unsubscribe_html']='Para cancelar suscripción de nuestro boletín, <a href="%s">haga clic en el enlace</a>.';
$lang['newsletter']['unsubscribe_txt']='Para cancelar suscripción de nuestro boletín, haga clic en el siguiente enlace:';

/*	rubrique d'aide
 *  	*/
$lang['newsletter']['help_add1']='Para añadir un boletín, inserte la información requerida en el formulario.';
$lang['newsletter']['help_add2']='Completado el formulario, revise los valores en el resumen.';
$lang['newsletter']['help_add3']='Validado el resumen, haga clic en "revisar valores" si desea hacer cambios.';


$lang['newsletter']['help_list1']='Para más información haga clic en el título del boletín.';
$lang['newsletter']['help_list2']="Para eliminar un boletín, haga clic en el icono 'eliminar boletín'.";
$lang['newsletter']['help_list3']="Para editar un boletín, haga clic en el icono 'editar boletín'.";
$lang['newsletter']['help_list4']='Para visualizar los boletines según su estado, mostrar por estados.';
$lang['newsletter']['help_list5']='Para añadir un boletín, haga clic en "añadir nuevo boletín".';
$lang['newsletter']['help_list6']="Si desea realizar búsquedas dentro del módulo 'boletines', haga clic en 'buscar'.";


$lang['newsletter']['help_mod1']='Para editar un boletín, complete la información requerida en el formulario.';
$lang['newsletter']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['newsletter']['help_mod3']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';


$lang['newsletter']['help_det1']="Para eliminar un boletín, haga clic en el icono 'eliminar boletín.'";
$lang['newsletter']['help_det2']="Para editar un boletín, haga clic en el icono 'editar boletín'.";

$lang['newsletter']['help_sup1']="Para abortar la eliminación, haga clic en 'cancelar'.";
?>
